==> react-native-cometchat-calling-component-3.0.3.tgz: package/components/AudioModeButton.js <==
import React, { Component } from "react";
import {
  View,
  TouchableOpacity,
  Image,
  NativeEventEmitter,
} from "react-native";
import AudioMode from "../AudioMode";
import Logger from "react-native-cometchat-calling-component/lib/Logger";
const AudioModeEmitter = new NativeEventEmitter(AudioMode);

const devices = {
  HEADPHONES: "HEADPHONES",
  SPEAKER: "SPEAKER",
  EARPIECE: "EARPIECE",
  BLUETOOTH: "BLUETOOTH",
};

const TAG = "AudioModeButton";

class AudioModeButton extends Component {
  state = {
    selectedDevice: null,
    availableDevices: {},
  };

  constructor(props) {
    super(props);
    if(this.props.isAudioOnly){
      AudioMode.setMode(AudioMode.AUDIO_CALL);
    }else{
      AudioMode.setMode(AudioMode.VIDEO_CALL);
      AudioMode.setAudioDevice(devices.SPEAKER);
    }
  }

  componentDidMount() {
    AudioModeEmitter.addListener(AudioMode.DEVICE_CHANGE_EVENT, (devices) => {
      let availableDevices = {};
      let selectedDevice;
      devices.forEach((device) => {
        availableDevices[device.type] = device;
        if (device.selected) {
          selectedDevice = device.type;
        }
      });

      if (selectedDevice) {
        this.setState({
          selectedDevice,
          availableDevices,
        });
      }
    });
  }

  getDeviceByPriority = () => {
    if (this.state.availableDevices[devices.HEADPHONES]) {
      return devices.HEADPHONES;
    } else if (this.state.availableDevices[devices.BLUETOOTH]) {
      return devices.BLUETOOTH;
    } else if (this.state.availableDevices[devices.EARPIECE]) {
      return devices.EARPIECE;
    } else {
      return this.state.availableDevices[devices.SPEAKER];
    }
  };

  routeAudioToSpeaker = () => {
    AudioMode.setAudioDevice(devices.SPEAKER);
  };

  routeAudioToDefaultMode = () => {
    AudioMode.setAudioDevice(this.getDeviceByPriority());
  };

  renderSpeakerIcon() {
    this.props.onAudioModeChanged('speaker')
    return (
      <TouchableOpacity onPress={this.routeAudioToDefaultMode}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/speaker_phone.png")}
        />
      </TouchableOpacity>
    );
  }

  renderEarPieceIcon() {
    this.props.onAudioModeChanged('ear piece')
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/icon_earpiece.png")}
        />
      </TouchableOpacity>
    );
  }

  renderHeadphoneIcon() {
    this.props.onAudioModeChanged('head phone')
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/headphones_pluged.png")}
        />
      </TouchableOpacity>
    );
  }

  renderBluetoothIcon() {
    this.props.onAudioModeChanged('bluetooth')
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/icon_bluetooth.png")}
        />
      </TouchableOpacity>
    );
  }

  renderIcon = () => {

    switch (this.state.selectedDevice) {
      case devices.SPEAKER:
        return this.renderSpeakerIcon();
      case devices.BLUETOOTH:
        return this.renderBluetoothIcon();
      case devices.HEADPHONES:
        return this.renderHeadphoneIcon();
      case devices.EARPIECE:
        return this.renderEarPieceIcon();
      default:
        return this.renderSpeakerIcon();
    }
    
  };

  render() {
    if(this.props.renderButton){
      return <View style={this.style.lt_control_view}>{this.renderIcon()}</View>;
    }else{
      return null;
    }
  }
    

  style = {
    lt_control_icon: { width: 25, height: 25 },
    lt_control_view: { width: 55, height: 55, margin: 1, backgroundColor: '#4d4c4f', borderRadius: 50, alignItems: 'center', justifyContent:'center' }
  };
}

export default AudioModeButton;

==> react-native-cometchat-calling-component-3.0.6.tgz: package/components/AudioModeButton.js <==
import React, { Component } from "react";
import {
  View,
  TouchableOpacity,
  Image,
  NativeEventEmitter,
} from "react-native";
import AudioMode from "../AudioMode";
import Logger from "../lib/Logger";
const AudioModeEmitter = new NativeEventEmitter(AudioMode);

const devices = {
  HEADPHONES: "HEADPHONES",
  SPEAKER: "SPEAKER",
  EARPIECE: "EARPIECE",
  BLUETOOTH: "BLUETOOTH",
};

const TAG = "AudioModeButton";

class AudioModeButton extends Component {
  state = {
    selectedDevice: null,
    availableDevices: {},
  };

  constructor(props) {
    super(props);
    if (this.props.isAudioOnly) {
      AudioMode.setMode(AudioMode.AUDIO_CALL);
    } else {
      AudioMode.setMode(AudioMode.VIDEO_CALL);
      AudioMode.setAudioDevice(devices.SPEAKER);
    }
  }

  componentDidMount() {
    AudioModeEmitter.addListener(AudioMode.DEVICE_CHANGE_EVENT, (devices) => {
      let availableDevices = {};
      let selectedDevice;
      devices.forEach((device) => {
        availableDevices[device.type] = device;
        if (device.selected) {
          selectedDevice = device.type;
        }
      });

      if (selectedDevice) {
        this.setState({
          selectedDevice,
          availableDevices,
        });
      }
    });
  }

  getDeviceByPriority = () => {
    if (this.state.availableDevices[devices.HEADPHONES]) {
      return devices.HEADPHONES;
    } else if (this.state.availableDevices[devices.BLUETOOTH]) {
      return devices.BLUETOOTH;
    } else if (this.state.availableDevices[devices.EARPIECE]) {
      return devices.EARPIECE;
    } else {
      return this.state.availableDevices[devices.SPEAKER];
    }
  };

  routeAudioToSpeaker = () => {
    AudioMode.setAudioDevice(devices.SPEAKER);
  };

  routeAudioToDefaultMode = () => {
    AudioMode.setAudioDevice(this.getDeviceByPriority());
  };

  renderSpeakerIcon() {
    this.props.onAudioModeChanged("speaker");
    return (
      <TouchableOpacity onPress={this.routeAudioToDefaultMode}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/speaker_phone.png")}
        />
      </TouchableOpacity>
    );
  }

  renderEarPieceIcon() {
    this.props.onAudioModeChanged("ear piece");
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/icon_earpiece.png")}
        />
      </TouchableOpacity>
    );
  }

  renderHeadphoneIcon() {
    this.props.onAudioModeChanged("head phone");
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/headphones_pluged.png")}
        />
      </TouchableOpacity>
    );
  }

  renderBluetoothIcon() {
    this.props.onAudioModeChanged("bluetooth");
    return (
      <TouchableOpacity onPress={this.routeAudioToSpeaker}>
        <Image
          style={this.style.lt_control_icon}
          source={require("../icons/icon_bluetooth.png")}
        />
      </TouchableOpacity>
    );
  }

  renderIcon = () => {
    switch (this.state.selectedDevice) {
      case devices.SPEAKER:
        return this.renderSpeakerIcon();
      case devices.BLUETOOTH:
        return this.renderBluetoothIcon();
      case devices.HEADPHONES:
        return this.renderHeadphoneIcon();
      case devices.EARPIECE:
        return this.renderEarPieceIcon();
      default:
        return this.renderSpeakerIcon();
    }
  };

  render() {
    if (this.props.renderButton) {
      return (
        <View style={this.style.lt_control_view}>{this.renderIcon()}</View>
      );
    } else {
      return null;
    }
  }

  style = {
    lt_control_icon: { width: 25, height: 25 },
    lt_control_view: {
      width: 55,
      height: 55,
      margin: 1,
      backgroundColor: "#4d4c4f",
      borderRadius: 50,
      alignItems: "center",
      justifyContent: "center",
    },
  };
}

export default AudioModeButton;
